@@ -5,7 +5,7 @@
 /* Copyright (C) 1995--present Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
    You may redistribute and/or modify NCO under the terms of the 
-   GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
+   3-Clause BSD License with exceptions described in the LICENSE file */
 
 /* Usage:
    #include "nco.h" *//* netCDF Operator (NCO) definitions */
@@ -348,7 +348,7 @@ extern "C" {
 # define NCO_VERSION_MINOR 9
 #endif /* !NCO_VERSION_MINOR */
 #ifndef NCO_VERSION_PATCH
-# define NCO_VERSION_PATCH 1
+# define NCO_VERSION_PATCH 3
 #endif /* !NCO_VERSION_PATCH */
 #ifndef NCO_VERSION_NOTE
 # define NCO_VERSION_NOTE "" /* Blank for final versions, non-blank (e.g., "-beta37") for pre-release versions */
@@ -358,7 +358,7 @@ extern "C" {
 # define NCO_LIB_VERSION ( NCO_VERSION_MAJOR * 100 + NCO_VERSION_MINOR * 10 + NCO_VERSION_PATCH )
 #endif /* !NCO_LIB_VERSION */
 #ifndef NCO_VERSION
-# define NCO_VERSION "4.9.1"
+# define NCO_VERSION "4.9.3"
 #endif /* !NCO_VERSION */
 
 /* Compatibility tokens new to netCDF4 netcdf.h: */
@@ -531,6 +531,12 @@ extern "C" {
 #endif
 #ifndef NC_EDAPSVC
 # define NC_EDAPSVC (-70)      /**< DAP server error */
+#endif
+
+  /* Backwards-compatibility error codes implemented in 202004 to workaround netCDF 4.7.4 backwards incompatibility with nc_inq_var_filter()
+     Currently used only in nco_prn.c */
+#ifndef NC_ENOFILTER
+# define NC_ENOFILTER (-136)      /**< Filter not defined on variable. */
 #endif
 
   /* NCO began using MIN/MAX tokens in nco_pck.c on 20101130
@@ -1078,7 +1084,7 @@ extern "C" {
   } nco_ply_tri_mth_typ_enm;
 
   typedef enum nco_edg_typ_enm{ /* [enm] Edge-type/arc-type that connects grid vertices */
-    nco_edg_nil=0,
+    nco_edg_nil=0, /* [enm] Edges/arcs are of unspecified type */
     nco_edg_gtc, /* [enm] Edges/arcs are great circle segments */
     nco_edg_smc, /* [enm] Edges/arcs of constant latitude are small circle segments, all others are great circle segments */
     nco_edg_crt, /* [enm] Edges/arcs are Cartesian/planar lines and neglect curvature */
@@ -1243,7 +1249,9 @@ extern "C" {
     int in_id; /* [id] Input netCDF file ID */
     int out_id; /* [id] Output netCDF file ID */
     int rgr_nbr; /* [nbr] Number of regridding arguments */
+    int thr_nbr; /* [nbr] Thread number */
     int xtn_nbr; /* [nbr] Number of extensive variables */
+    int area_mth; /* [enm]  area method used calculating grid cell area */
     long idx_dbg; /* [idx] Index of gridcell for debugging */
     long tst; /* [enm] Generic key for testing (undocumented) */
     nco_bool flg_area_out; /* [flg] Add area to output */
@@ -1262,6 +1270,7 @@ extern "C" {
     nco_bool flg_rnr; /* [flg] Renormalize destination values by valid area */
     nco_bool flg_stg; /* [flg] Write staggered grid with FV output */
     nco_bool flg_usr_rqs; /* [flg] User-requested regridding */
+    size_t hdr_pad; /* [B] Pad at end of header section (for map-file only) */
   } rgr_sct; /* end Regrid structure */
 
   /* Key-value structure */
