@@ -586,7 +586,7 @@ void sel_k(KDElem *items, double k, int disc, KDElem **lo, KDElem **eq, KDElem *
     *lo = *eq = *hi = (KDElem *)NULL;
 	*lomean = *himean = 0.0;
 	*locount = *hicount = 0;
-    lo_val = DBL_MAX;
+    lo_val = KD_DBL_MAX;
     
     median = (KDElem *)NULL;
     while (idx)
@@ -720,8 +720,8 @@ int get_min_max(KDElem *list, int disc, double *b_min, double *b_max)
     KDElem *item;
     int count;
 
-    *b_min = DBL_MAX;
-    *b_max = -(DBL_MAX);
+    *b_min = KD_DBL_MAX;
+    *b_max = -(KD_DBL_MAX);
 
     disc = disc & 0x01;		/* zero: horizontal, one: vertical */
     count = 0;
@@ -1001,12 +1001,12 @@ KDElem *find_item(KDElem *elem, int disc, kd_generic item, kd_box size, int sear
 				items_elem->size[2] = size[2];
 				items_elem->size[3] = size[3];
 				items_elem->lo_min_bound = size[vert];
-				items_elem->hi_max_bound = size[vert+2];
-				items_elem->other_bound = (((disc+1)%4 & 0x2) ? size[vert] : size[vert+2]);
+				items_elem->hi_max_bound = size[vert + 2];
+				items_elem->other_bound = (((disc + 1) % 4 & 0x2) ? size[vert] : size[vert + 2]);
 				items_elem->sons[0] = 0;
 				items_elem->sons[1] = 0;
 				items_elem->item = item;
-				
+
 			}
 			else
 				elem->sons[ival] = kd_new_node(item, size, size[vert], size[vert+2], (((disc+1)%4 & 0x2) ? size[vert] : size[vert+2]), (KDElem *) NULL, (KDElem *) NULL);
@@ -1674,10 +1674,10 @@ void unload_items(KDTree* rootTree, KDElem **nodelist, kd_box extent, long *item
 {
 	/* traverse the tree and collect the nodes bottom-up into a single list; delete
 	   dead nodes, freeing them */
-        extent[KD_LEFT] =   DBL_MAX;
-	extent[KD_BOTTOM] = DBL_MAX;
-	extent[KD_RIGHT] =  -DBL_MAX;
-	extent[KD_TOP] =    -DBL_MAX;
+        extent[KD_LEFT] =   KD_DBL_MAX;
+	extent[KD_BOTTOM] = KD_DBL_MAX;
+	extent[KD_RIGHT] =  -KD_DBL_MAX;
+	extent[KD_TOP] =    -KD_DBL_MAX;
 	
 	
 	collect_nodes(rootTree, rootTree->tree, nodelist, extent, items, mean);
@@ -2497,67 +2497,41 @@ int kd_neighbour_intersect3(KDElem *node, int disc, kd_box Xq, omp_mem_sct *omp_
 
   }
 
-  if( stateH==2 && stateV==2 )
-  	bAddPnt=True;
-  else if(stateH==2 && stateV==1  && node->size[KD_TOP] >= Xq[KD_BOTTOM]  && node->size[KD_BOTTOM] <= Xq[KD_TOP] )
-     bAddPnt=True;
-  else if(stateH==1 && stateV==2 &&  node->size[KD_RIGHT] >= Xq[KD_LEFT]  && node->size[KD_LEFT] <= Xq[KD_RIGHT]  )
-  	bAddPnt=True;
-  else  if(BOXINTERSECT(node->size, Xq))
-	  bAddPnt=True;
+  if(stateH == 2 && stateV == 2) bAddPnt=True;
+  else if(stateH == 2 && stateV == 1 && node->size[KD_TOP] >= Xq[KD_BOTTOM] && node->size[KD_BOTTOM] <= Xq[KD_TOP]) bAddPnt=True;
+  else if(stateH == 1 && stateV == 2 && node->size[KD_RIGHT] >= Xq[KD_LEFT] && node->size[KD_LEFT] <= Xq[KD_RIGHT]) bAddPnt=True;
+  else if(BOXINTERSECT(node->size,Xq)) bAddPnt=True;
 
-	/* add node as necessary */
-  if(bAddPnt)
-  { 
+  /* add node as necessary */
+  if(bAddPnt){ 
+    if(omp_mem->kd_blk_nbr*NCO_VRL_BLOCKSIZE < omp_mem->kd_cnt+1){
+      /* fxm */
+      (void)fprintf(stderr,"%s: ERROR %s reports that the kd-tree overlap buffer (size=%d) is now full and currenly cannot be dynamically expanded. We are trying to fix this. In the meanwhile consider increasing NCO_VRL_BLOCKSIZE in nco_kd.h, and then re-compiling.\n",nco_prg_nm_get(),fnc_nm,NCO_VRL_BLOCKSIZE);
+      nco_exit(EXIT_FAILURE);
 
+      /*
+        omp_mem->kd_list=(KDPriority*)nco_realloc(omp_mem->kd_list,++omp_mem->kd_blk_nbr*(NCO_VRL_BLOCKSIZE*sizeof(KDPriority)));
+        (void)fprintf(stderr,"%s: Increasing block size to %ld kd_cnt=%ld omp_mem=%p\n",fnc_nm,omp_mem->kd_blk_nbr,omp_mem->kd_cnt,(void*)omp_mem->kd_list);
+      */
+    } /* !omp_mem */
+    omp_mem->kd_list[omp_mem->kd_cnt].elem = node;
+    omp_mem->kd_list[omp_mem->kd_cnt].dist = 1.0;
+    omp_mem->kd_list[omp_mem->kd_cnt++].area = -1.0;
+  } /* !baddPnt */
 
-  	 if( omp_mem->kd_blk_nbr * NCO_VRL_BLOCKSIZE < omp_mem->kd_cnt +1 )
-	 {
-
-        /* fixme: */
-        (void)fprintf(stderr,"%s:%s(): The overlap buffer is now full (size=%d) and currenly cannot be dynamically expanded\n We are trying to fix this. "\
-							 "In the meanwhile consider going into nco_kd.h  and editing NCO_VRL_BLOCKSIZE, and then re-compiling\n", nco_prg_nm_get(),fnc_nm, NCO_VRL_BLOCKSIZE     );
-
-	    nco_exit( EXIT_FAILURE );
-
-	    /*
-        omp_mem->kd_list=(KDPriority*)nco_realloc(omp_mem->kd_list, ++omp_mem->kd_blk_nbr * (NCO_VRL_BLOCKSIZE *sizeof(KDPriority))  );
-        (void)fprintf(stderr,"%s: Increasing block size to %ld kd_cnt=%ld omp_mem=%p\n",fnc_nm, omp_mem->kd_blk_nbr, omp_mem->kd_cnt,   (void*)omp_mem->kd_list );
-        */
-
-     }
-
-
-  	 omp_mem->kd_list[omp_mem->kd_cnt].elem = node;
-  	 omp_mem->kd_list[omp_mem->kd_cnt].dist = 1.0;
-  	 omp_mem->kd_list[omp_mem->kd_cnt++].area = -1.0;
-
-
-
-
-  }
-     
-  
-
-  if( node->sons[0] )
-  {
+  if(node->sons[0]){
     //iret= kd_neighbour_intersect3(node->sons[0], (disc+1)%4, Xq, list_head,  list_end, stateH, stateV);
     iret= kd_neighbour_intersect3(node->sons[0], (disc+1)%4, Xq, omp_mem, stateH, stateV);
     if(iret==0) return iret;
-      
   }
      
-  if( node->sons[1] )
-  {  
+  if(node->sons[1]){  
     //iret=kd_neighbour_intersect3(node->sons[1], (disc+1)%4,  Xq, list_head,  list_end, stateH, stateV);
     iret=kd_neighbour_intersect3(node->sons[1], (disc+1)%4,  Xq, omp_mem, stateH, stateV);
     if(iret==0) return iret;
-       
   }
 
-
   return 1;
-  
 }
 
 int kd_priority_cmp( const void *vp1, const void *vp2)
@@ -2572,8 +2546,6 @@ int kd_priority_cmp( const void *vp1, const void *vp2)
   return ( df < 0 ? -1 :  df >0 ? 1 : 0   );
 }
 
-
-
 /* Sorts input list
  * if duplicates then copy new list over to old and True returned
  * no duplicates then sorted list remains and False is returned
@@ -2635,7 +2607,7 @@ int kd_nearest(KDTree* realTree, double x, double y, int m, KDPriority **alist)
 	*alist = (KDPriority *)nco_calloc(sizeof(KDPriority),m);
 	for(idx=0;idx<m;idx++)
 	{
-	  (*alist)[idx].dist = DBL_MAX;
+	  (*alist)[idx].dist = KD_DBL_MAX;
 	  (*alist)[idx].elem = (KDElem*)NULL;
 	}
 
@@ -2650,7 +2622,7 @@ int kd_nearest(KDTree* realTree, double x, double y, int m, KDPriority **alist)
 	return kd_neighbour(realTree->tree,Xq,m,*alist,Bp,Bn);
 }
 
-int kd_nearest_intersect_wrp(KDTree *realTree, kd_box Xq, kd_box Xr, omp_mem_sct *omp_mem)
+int kd_nearest_intersect_wrp(KDTree **rTree, int nbr_tr, kd_box Xq, kd_box Xr, omp_mem_sct *omp_mem)
 {
   /* count duplicates for dbg */
   int ret_cnt_nw=0;
@@ -2662,8 +2634,11 @@ int kd_nearest_intersect_wrp(KDTree *realTree, kd_box Xq, kd_box Xr, omp_mem_sct
   //  const char fnc_nm[]="kd_nearest_intersect_wrp():";
   // (void)fprintf(stderr,"%s:%s: just entered function\n", nco_prg_nm_get(),fnc_nm );
 
-  ret_cnt=kd_nearest_intersect(realTree,Xq,omp_mem, bSort);
-  ret_cnt1=kd_nearest_intersect(realTree,Xr, omp_mem, bSort);
+
+  ret_cnt = kd_nearest_intersect(rTree, nbr_tr,Xq, omp_mem, bSort);
+
+  ret_cnt1 = kd_nearest_intersect(rTree,nbr_tr, Xr, omp_mem, bSort);
+
 
   if( omp_mem->kd_cnt >1  &&  kd_priority_list_sort(omp_mem->kd_list,  omp_mem->kd_blk_nbr* NCO_VRL_BLOCKSIZE, omp_mem->kd_cnt , &ret_cnt_nw  )  )
     omp_mem->kd_cnt=ret_cnt_nw;
@@ -2672,13 +2647,13 @@ int kd_nearest_intersect_wrp(KDTree *realTree, kd_box Xq, kd_box Xr, omp_mem_sct
 }
 
 //int kd_nearest_intersect(KDTree* realTree, kd_box Xq, int m, KDPriority *list, int bSort)
-int kd_nearest_intersect(KDTree* realTree, kd_box Xq, omp_mem_sct *omp_mem, int bSort)
+int kd_nearest_intersect(KDTree** rTree, int nbr_tr, kd_box Xq, omp_mem_sct *omp_mem, int bSort)
 {
   int idx;
   int nw_lcl_cnt=0;
   int ret_cnt=0;
   
-   const char fnc_nm[]="kd_nearest_intersect():";
+  //const char fnc_nm[]="kd_nearest_intersect()";
 
    //(void)fprintf(stderr,"%s:%s: just entered function\n", nco_prg_nm_get(),fnc_nm );
     /*
@@ -2688,16 +2663,21 @@ int kd_nearest_intersect(KDTree* realTree, kd_box Xq, omp_mem_sct *omp_mem, int
 	list_end+=m;
    */
    //node_cnt= kd_neighbour_intersect3(realTree->tree,0,Xq, &list_srt ,list_end,0,0);
-    (void)kd_neighbour_intersect3(realTree->tree,0,Xq, omp_mem,0,0);
+
+   for(idx=0;idx < nbr_tr;idx++)
+     (void)kd_neighbour_intersect3(rTree[idx]->tree,0,Xq, omp_mem,0,0);
 
     /*
     ret_cnt=( list_srt - omp_mem->kd_list)+ omp_mem->kd_cnt;
     if(ret_cnt > 1 && bSort && kd_priority_list_sort(omp_mem->kd_list, m, ret_cnt, &nw_lcl_cnt)) ret_cnt=nw_lcl_cnt;
     */
     ret_cnt=omp_mem->kd_cnt;
-    if(omp_mem->kd_cnt && bSort && kd_priority_list_sort(omp_mem->kd_list,  omp_mem->kd_blk_nbr * NCO_VRL_BLOCKSIZE, omp_mem->kd_cnt  , &nw_lcl_cnt)){
-    	ret_cnt=nw_lcl_cnt;
-    	omp_mem->kd_cnt=nw_lcl_cnt;
+    if(omp_mem->kd_cnt &&
+       bSort &&
+       kd_priority_list_sort(omp_mem->kd_list,omp_mem->kd_blk_nbr*NCO_VRL_BLOCKSIZE,omp_mem->kd_cnt,&nw_lcl_cnt)
+       ){
+      ret_cnt=nw_lcl_cnt;
+      omp_mem->kd_cnt=nw_lcl_cnt;
     }
 
     if(0 && nco_dbg_lvl_get() >= nco_dbg_dev)
