@@ -5,7 +5,7 @@
 /* Copyright (C) 2015--present Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
    You may redistribute and/or modify NCO under the terms of the 
-   GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
+   3-Clause BSD License with exceptions described in the LICENSE file */
 
 /* Usage:
    #include "nco_map.h" *//* Map generation */
@@ -32,6 +32,7 @@
 #include "nco_sng_utl.h" /* String utilities */
 #include "nco_ply_lst.h"  /* polygon list functions */
 #include "nco_ply.h"     /* polygon functions */
+#include "nco_kd.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -90,7 +91,8 @@ extern "C" {
   (const char *fl_out,
    poly_sct ** pl_lst,
    int pl_nbr,
-   nco_grd_lon_typ_enm grd_lon_typ
+   nco_grd_lon_typ_enm grd_lon_typ,
+   int fl_out_fmt
    );
   
   int
@@ -101,15 +103,7 @@ extern "C" {
    const char *att_nm,
    const char *att_val
    );
-  
-  void
-  nco_msh_plg_area /* [fnc] wrapper to nco_sph_plg_area() */
-  (const double * const lat_bnd, /* [dgr] Latitude  boundaries of rectangular grid */
-   const double * const lon_bnd, /* [dgr] Longitude boundaries of rectangular grid */
-   const long grd_sz_nbr, /* [nbr] Number of gridcells in grid */
-   const int bnd_nbr, /* [nbr] Number of bounds in gridcell */
-   double * const area_out); /* [sr] Gridcell area */
-  
+
   nco_bool
   nco_map_hst_mk
   (var_sct* var_row,
@@ -135,6 +129,7 @@ extern "C" {
   nco_bool
   nco_map_chk
   (const char *fl_in,
+   nco_bool flg_frac_b_nrm,
    nco_bool flg_area_wgt);
   
   nco_bool
@@ -151,7 +146,19 @@ extern "C" {
    var_sct *var_area_a,
    var_sct *var_area_b,
    var_sct *var_frac_a);
-  
+
+
+  KDTree *
+  nco_map_kd_init
+  (poly_sct **pl_lst,
+   int pl_cnt,
+   nco_grd_lon_typ_enm grd_lon_typ);
+
+  void
+  nco_poly_area_add
+  (poly_sct *pl);
+
+
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* __cplusplus */
