@@ -5,7 +5,7 @@
 /* Copyright (C) 2018--present Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
    You may redistribute and/or modify NCO under the terms of the 
-   GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
+   3-Clause BSD License with exceptions described in the LICENSE file */
 
 /* Usage:
    #include "nco_ply_lst.h" *//* Polygon list manipulation */
@@ -34,9 +34,6 @@
 extern "C" {
 #endif /* !__cplusplus */
 
-
-/************************ functions that manipulate lists of polygons ****************************************************/
-
 void
 nco_poly_re_org_lst(  /* for each poly_sct*  in list re-order points so that first point is the leftermost point */
 poly_sct **pl_lst,
@@ -68,8 +65,6 @@ size_t grd_sz, /* I [nbr] Number of elements in single layer of source grid */
 long grd_crn_nbr, /* I [nbr] Maximum number of corners in source gridcell */
 nco_grd_lon_typ_enm grd_lon_typ); /* I [num] if not nil then split cells that straddle Greenwich or Dateline  */
 
-
-
 poly_sct**             /* [O] [nbr] Array of poly_sct */
 nco_poly_lst_mk_sph(
 double *area, /* I [sr] Area of source grid */
@@ -82,16 +77,11 @@ size_t grd_sz, /* I [nbr] Number of elements in single layer of source grid */
 long grd_crn_nbr, /* I [nbr] Maximum number of corners in source gridcell */
 nco_grd_lon_typ_enm grd_lon_typ); /* I [num] if not nil then split cells that straddle Greenwich or Dateline  */
 
-
-
-
-
 poly_sct **
 nco_poly_lst_free(
 poly_sct **pl_lst,
 int arr_nbr);
 
-
 poly_sct **
 nco_poly_lst_mk_vrl(   /* create overlap mesh  for crt */
 poly_sct **pl_lst_in,
@@ -99,23 +89,20 @@ int pl_cnt_in,
 KDTree *rtree,
 int *pl_cnt_vrl_ret);
 
-
-
 poly_sct **
 nco_poly_lst_mk_vrl_sph(  /* create overlap mesh  for sph polygons */
 poly_sct **pl_lst_in,
 int pl_cnt_in,
 nco_grd_lon_typ_enm grd_lon_typ,
-KDTree *rtree,
+KDTree **tree,
+int nbr_tr,
 int *pl_cnt_vrl_ret);
 
-
 void
 nco_poly_set_priority(
 int nbr_lst,
 KDPriority *list);
 
-
 /* create list for debugging */
 poly_sct **
 nco_poly_lst_chk_dbg(
@@ -126,7 +113,6 @@ int pl_cnt_vrl,
 int io_flg,  /* [flg] 0 - use src_id from vrl, 1 - use dst_id from vrl */
 int *pl_cnt_dbg); /* size of output dbg grid */
 
-
 /* check areas */
 void nco_poly_lst_chk(
 poly_sct **pl_lst_in,
@@ -136,8 +122,6 @@ int pl_cnt_out,
 poly_sct **pl_lst_vrl,
 int pl_cnt_vrl);
 
-
-
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* !__cplusplus */
