@@ -5,7 +5,7 @@
 /* Copyright (C) 1995--present Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
    You may redistribute and/or modify NCO under the terms of the 
-   GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
+   3-Clause BSD License with exceptions described in the LICENSE file */
 
 #include "nco_scm.h" /* Software configuration management */
 
@@ -148,8 +148,8 @@ void
 nco_cpy_prn(void) /* [fnc] Print copyright notice */
 {
   /* Purpose: Print copyright notice */
-  (void)fprintf(stderr,"Copyright (C) 1995--2019 Charlie Zender\n");
-  (void)fprintf(stdout,"This program is part of NCO, the netCDF Operators.\nNCO is free software and comes with a BIG FAT KISS and ABSOLUTELY NO WARRANTY\nYou may redistribute and/or modify NCO under the terms of the\nGNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file\nGPL: http://www.gnu.org/copyleft/gpl.html\nLICENSE: https://github.com/nco/nco/tree/master/LICENSE\n");
+  (void)fprintf(stderr,"Copyright (C) 1995--2020 Charlie Zender\n");
+  (void)fprintf(stdout,"This program is part of NCO, the netCDF Operators.\nNCO is free software and comes with a BIG FAT KISS and ABSOLUTELY NO WARRANTY\nYou may redistribute and/or modify NCO under the terms of the\n3-Clause BSD License with exceptions described in the LICENSE file\nBSD: https://opensource.org/licenses/BSD-3-Clause\nLICENSE: https://github.com/nco/nco/tree/master/LICENSE\n");
 } /* end copyright_prn() */
 
 void
@@ -205,8 +205,10 @@ nco_lbr_vrs_prn(void) /* [fnc] Print netCDF library version */
 const char * /* O [sng] Mnemonic that describes current NCO version */
 nco_nmn_get(void) /* [fnc] Return mnemonic that describes current NCO version */
 { 
-  /* Purpose: Return mnemonic describing current NCO version */
-  return "Skyglow";
+  /* Purpose: Return mnemonic describing current NCO version 
+     20191221: ncremap/ncclimo print left quote and first word of this string, so one-word strings look best 
+     20200117: fixed this limitation, multi-word versions seem to work */
+  return "Outlander";
 } /* end nco_nmn_get() */
 
 void
@@ -230,7 +232,7 @@ nco_vrs_prn /* [fnc] Print NCO version */
 
   char vrs_cpp[]=TKN2SNG(NCO_VERSION); /* [sng] Version from C pre-processor */
 
-  /* 20170417: vrs_cpp is typically something like "4.6.6-alpha08" (quotes included) 
+  /* 20170417: vrs_cpp is typically something like "4.6.6-alpha09" (quotes included) 
      The quotation marks annoy me yet are necessary to protect the string in nco.h 
      Here we remove the quotation marks by pointing past the first and putting NUL in the last */
   char *vrs_sng; /* [sng] NCO version */
