@@ -7,7 +7,7 @@
    Copyright (C) 2018--present Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
    You may redistribute and/or modify NCO under the terms of the 
-   GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
+   3-Clause BSD License with exceptions described in the LICENSE file */
 
 /* This copyright statement and license terms for modification and redistribution 
    of the original code were agreed to by the original author, Joseph O'Rourke, on 20190517:
@@ -56,6 +56,17 @@
 #include        <stdio.h>
 #include        <math.h>
 
+#ifdef HAVE_CONFIG_H
+# include <config.h> /* Autotools tokens */
+#endif /* !HAVE_CONFIG_H */
+
+#ifdef ENABLE_GSL
+  #include <gsl/gsl_vector.h>
+  #include <gsl/gsl_matrix.h>
+  #include <gsl/gsl_permutation.h>
+  #include <gsl/gsl_linalg.h>
+#endif
+
 /* Personal headers */
 #include "nco.h" /* netCDF Operator (NCO) definitions */
 #include "nco_mmr.h"     /* Memory management */
@@ -101,6 +112,20 @@
 extern "C" {
 #endif /* !__cplusplus */
 
+/*---------------------------------------------------------------------
+Structures
+---------------------------------------------------------------------*/
+
+/* vertex info  */
+typedef struct {
+  poly_vrl_flg_enm  in_flag;  /* if P_in - vertex from a, Q_in Vertex from b */
+  int p_vrt;                  /* if -1 then genuine intersection */
+  int q_vrt;
+  double p0[NBR_SPH];           /* actual point - used for debuggging */
+}vrt_info_sct;
+
+
+
 /*---------------------------------------------------------------------
 Function prototypes.
 ---------------------------------------------------------------------*/
@@ -112,10 +137,17 @@ char
 nco_sph_seg_int_old(double *a, double *b, double *c, double *d, double *p, double *q);
 
 nco_bool
-nco_sph_seg_int(double *p0, double *p1, double *q0, double *q1, double *r0, double *r1, int flg_snp_to, char *codes);
+nco_sph_seg_int(double *p0, double *p1, double *q0, double *q1, double *r0, double *r1, int *pq_cross, int flg_snp_to, char *codes);
+
+int
+nco_sph_mk_pqcross( double *p0, double *p1, double *pCross, double *q0, double  *q1, double *qCross, int pqCross[], nco_edg_typ_enm rgr_edg_typ,   nco_edg_typ_enm *p_edg_typ, nco_edg_typ_enm *q_edg_typ);
+
+nco_bool
+nco_sph_seg_parallel(double *p0, double *p1, double *q0, double *q1, double *r0, double *r1, poly_vrl_flg_enm *inflag, char *codes );
+
+nco_bool
+nco_sph_seg_smc(double *p0, double *p1, double *q0, double *q1, double *r0, double *r1, int *pq_cross, int flg_snp_to, char *codes);
 
-char
-nco_sph_seg_parallel(double *p0, double *p1, double *q0, double *q1, double *r0, double *r1, poly_vrl_flg_enm *inflag );
 
 nco_bool
 nco_sph_seg_vrt_int(double *a, double *b, double *c);
@@ -135,6 +167,9 @@ nco_sph_dot_nm(double *a, double *b);
 double
 nco_sph_cross(double *a, double *b, double *c);
 
+double
+nco_sph_cross_sub(double *a, double *b, double *c);
+
 double
 nco_sph_cross2(double *a, double *b, double *c);
 
@@ -168,6 +203,12 @@ nco_sph_adi(double *a, double *b);
 void
 nco_sph_add_pnt(double **R, int *r, double *P);
 
+bool
+nco_sph_vrt_info_cmp( vrt_info_sct *info_a, vrt_info_sct *info_b);
+
+void
+nco_sph_add_pnt_chk( vrt_info_sct *vrt_info, poly_vrl_flg_enm inflag, int p_vrt, int q_vrt,  double **R, int *r, double *P);
+
 nco_bool
 nco_sph_between(double a, double b, double x);
 
@@ -214,6 +255,11 @@ nco_sph_metric( double *p, double *q);
 int
 nco_sph_metric_int(double *c, double *d, double *Icross);
 
+double
+nco_sph_area_karney( double **sP, int np);
+
+double
+nco_sph_area_quadrature(double  **sP, int np);
 
 /***************** nco_geo functions these manimpulate lat & lon  ***************************/
 void
@@ -237,8 +283,8 @@ nco_rll_intersect(poly_sct *P, poly_sct *Q, poly_sct *R, int *r);
 char
 nco_rll_seg_int(double *a, double *b, double *c, double *d, double *p, double *q);
 
-char
-nco_rll_seg_parallel(double *p0, double *p1, double *q0, double *q1, double *r0, double *r1, poly_vrl_flg_enm *inflag );
+nco_bool
+nco_rll_seg_parallel(double *p0, double *p1, double *q0, double *q1, double *r0, double *r1, poly_vrl_flg_enm *inflag, char *codes );
 
 void
 nco_rll_area(poly_sct *pl);
